"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OptionsBuilderHelper = void 0;
class OptionsBuilderHelper {
    constructor(config, flagPrefix = '--') {
        this._config = config;
        this._flagPrefix = flagPrefix;
    }
    get config() {
        return this._config;
    }
    buildFlags(flags) {
        return flags
            .filter(flag => this.config.get(flag, false))
            .map(flag => this.buildParameterExpression(flag));
    }
    buildParameters(parameters) {
        return parameters
            .map(parameter => {
            const value = this.config.get(parameter);
            return value
                ? [this.buildParameterExpression(parameter), value.toString()]
                : [];
        })
            .reduce((previous, current) => previous.concat(current), []);
    }
    buildListParameters(listParameters) {
        return listParameters
            .map(listParameter => {
            const list = this.config.get(listParameter, []);
            if (list.length > 0) {
                return [this.buildParameterExpression(listParameter), list.join(',')];
            }
            return [];
        })
            .reduce((previous, current) => previous.concat(current), []);
    }
    buildParameterExpression(name) {
        return this._flagPrefix + name;
    }
}
exports.OptionsBuilderHelper = OptionsBuilderHelper;
